===============================
mom_xtools
===============================


.. image:: https://img.shields.io/travis/jbusecke/mom_xtools.svg
   :target: https://travis-ci.com/jbusecke/mom_xtools
.. image:: https://codecov.io/gh/jbusecke/mom_xtools/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/jbusecke/mom_xtools
.. image:: https://img.shields.io/pypi/v/mom_xtools.svg
   :target: https://pypi.org/project/mom-xtools

Collection of xarray based analysis tools for MOM ocean model output
